#delimit ;
set mem 256m;
set matsize 100;
set more on;





use r_rating;
* code rating dummies;
gen g = (rating == "G");
gen pg = (rating == "PG");
gen pg13 = (rating == "PG-13");
gen r = (rating == "R");
* total content scores;
gen total = sex+violence+profanity;
* set aside;
keep g pg pg13 r rating total vtotbo dist degree meanr dir_exp;
save ratings, replace;


* 1) COMPOSITE SCORE DISTRIBUTIONS;
clear;
use ratings;
gen factor = total;
collapse (sum) g r pg13 pg, by(factor);
recode g r pg13 pg (0=.);
label var r "R";
label var pg13 "PG-13";
label var pg "PG";
label var g "G";
label var factor "Kids-in-mind composite score";
twoway scatter g factor, connect(l) msymbol(o) lpattern(solid) ||
       scatter pg factor, connect(l)  msymbol(d) lpattern(longdash) ||
       scatter pg13 factor, connect(l) msymbol(t) lpattern(shortdash) ||
       scatter r factor, connect(l) msymbol(s) lpattern(dash_dot)
       ytitle("Number of Movies") xlabel(#11) legend(subtitle("Legend: MPAA/CARA Rating")
       pos(2) ring(0)) title("Figure 1");
graph save fig1, replace;



* 2) R-RATING BY MPAA MAJOR AND COMPOSITE SCORE;
clear;
use ratings;
* variable for MAJOR studios;
gen major = (dist == "BUENA VISTA"
             | dist == "MGM/UA"
             | dist == "PARAMOUNT"
             | dist == "SONY PICTURES"
             | dist == "TWENTIETH CENTURY FOX"
             | dist == "UNIVERSAL"
             | dist == "WARNER BROS.");
* create buckets for graph;
gen r1 = (rating == "R" & major == 1);
gen n1 = (major == 1 );
gen r2 = (rating == "R" & major == 0);
gen n2 = (major == 0 );
* sum by content score categories;
gen factor = total;
collapse (sum) r1 n1 r2 n2, by(factor);
* recode sums to percentages;
replace r1 = r1/n1;
replace r2 = r2/n2;
* drop low count categories on tails;
drop if (n1+n2) < 20;
* label and graph;
label var factor "Kids-in-mind composite score";
label var r1 "MPAA Distributor";
label var r2 "non-MPAA Distributor";
twoway scatter r1 factor, connect(l) msymbol(o) lpattern(solid) ||
       scatter r2 factor, connect(l) msymbol(t) lpattern(shortdash)
	ytitle("% of Movies with an R rating") xlabel(#11) legend(subtitle("Legend: MPAA Membership Status")
        pos(11) ring(0) cols(1)) title("Figure 2");
Graph save fig2, replace;



* 3) R-RATING BY CAST CENTRALITY AND COMPOSITE SCORE;
clear;
use ratings;
* create buckets for graph;
gen r1 = (rating == "R" & degree >= 20 );
gen n1 = (degree >= 20);
gen r2 = (rating == "R" & degree < 20 );
gen n2 = (degree < 20 );
* sum by content score categories;
gen factor = total;
collapse (sum) r1 n1 r2 n2, by(factor);
* recode sums to percentages;
replace r1 = r1/n1;
replace r2 = r2/n2;
* drop low count categories on tails;
drop if (n1+n2) < 20;
* label and graph;
label var factor "Kids-in-mind composite score";
label var r1 "High Centrality";
label var r2 "Low Centrality";
twoway scatter r1 factor, connect(l) msymbol(o) lpattern(solid)
   || scatter r2 factor, connect(l) msymbol(t) lpattern(shortdash)
    ytitle("% of Movies with an R rating") xlabel(#11) legend(subtitle("Legend: Producer/Director Centrality")
        pos(11) ring(0) cols(1)) title("Figure 3");
Graph save fig3, replace;



* 4) R-RATING BY PRIOR R AND COMPOSITE SCORE;
clear;
use ratings;
* drop cases where director has no prior rated films;
keep if dir_exp > 0;
* create buckets for graph;
gen r1 = (rating == "R" & meanr < .5 );
gen n1 = (meanr < .5 );
gen r2 = (rating == "R" & meanr >= .5 );
gen n2 = (meanr >= .5 );
* sum by content score categories;
gen factor = total;
collapse (sum) r1 n1 r2 n2, by(factor);
* recode sums to percentages;
replace r1 = r1/n1;
replace r2 = r2/n2;
* drop low count categories on tails;
drop if (n1+n2) < 20;
* label and graph;
label var factor "Kids-in-mind composite score";
label var r1 "Low Prior R";
label var r2 "High Prior R";
twoway scatter r1 factor, connect(l) msymbol(o) lpattern(solid)
   || scatter r2 factor, connect(l) msymbol(t) lpattern(shortdash)
    ytitle("% of Movies with an R rating") xlabel(#11) legend(subtitle("Legend: Director Prior R")
        pos(11) ring(0) cols(1)) title("Figure 4");
Graph save fig4, replace;




* 5) COMPOSITE, RATING AND BOX OFFICE;
clear;
use ratings;
gen factor = total;
gen lnbo = ln(vtotbo+1);
gen pgbo = lnbo if rating == "PG" | rating == "PG-13"; 
gen rbo = lnbo if rating == "R"; 
collapse (mean) rbo  pgbo 
	(count) nr = rbo npg = pgbo
	(sd) sdr = rbo sdpg = pgbo, by(factor);
replace pgbo = . if npg < 20;
replace rbo = . if nr < 20;
drop if pgbo == . & rbo == .;
gen pgm1 = pgbo - sdpg;
gen pgp1 = pgbo + sdpg;
gen rm1 = rbo - sdr;
gen rp1 = rbo + sdr;
gen factor1 = factor-.05;
gen factor3 = factor+.05;
label var rbo "R";
label var pgbo "PG-13/PG";
twoway  scatter pgbo factor1, connect(l) msymbol(o) lcolor(dkgreen) mcolor(dkgreen)||
        rcap pgm1 pgp1 factor1, lwidth(vthin) lcolor(dkgreen) mcolor(dkgreen)||
        scatter rbo factor3, connect(l) msymbol(t) lcolor(maroon) mcolor(maroon) lpattern(shortdash) ||
        rcap rm1 rp1 factor3, lwidth(vthin) lcolor(maroon) mcolor(maroon)
        ytitle("Average Box Office (ln $)") xlabel(#11)
        xtitle("Kids-in-mind composite score")
        legend(subtitle("Legend: MPAA/CARA Rating") order(1 3) pos(7) ring(0)) title("Figure 5");
graph save fig5, replace;

erase ratings.dta;
