#delimit ;
set mem 160m;



/* Kids in Mind (downloaded Jan 24 2008) lists 2498 movies rated
from 1992 to 2006.  We merged these titles with the Variety weekly
box office report and IMDB (April 20 2007). 94 of the 2498 Kids in Mind
Titles were dropped from analysis:
1) 24 titles not found in Variety
2) 2 movies rated NC-17
3) 18 unrated movies
4) 33 documentaries
5) 4 titles theatrically released prior to 1992 or after 2006
6) 13 titles where there  is a 2+ year discrepancy between the original
US release date listed by Variety and the screening date listed
by Kids in Mind. These appear to be mostly foreign movies that are more
broadly re-released in the US.  For instance, several Jackie Chan movies are
reviewed by Kids in Mind several years after the original US theatrical release. 

In the 2404 remaining titles both Kids in Mind and Variety indicate
the same release year for 2317 titles. In all cases we use the Variety
release date to calculate year dummy variables

*/

use r_rating;
* create dependent variable: 1 = US R-Rating;
gen r = (rating == "R");
* variable for MAJOR studios;
gen major = (dist == "BUENA VISTA"
             | dist == "MGM/UA"
             | dist == "PARAMOUNT"
             | dist == "SONY PICTURES"
             | dist == "TWENTIETH CENTURY FOX"
             | dist == "UNIVERSAL"
             | dist == "WARNER BROS.");
label var major "Major";
* array of dummy variables for release year;
gen year = year(vprweek);
tab year, g(vyd);
* log transform distributor scale and cast centrality;
gen lnscale=ln(dist_exp+1);
label var lnscale "Distributor Exp.";
gen lndegree=ln(degree+1);
label var lndegree "Cast Centrality";
* content score fixed effects;
gen profanity2=profanity;
gen violence2=violence;
gen sex2=sex;
recode profanity2 0/1=0 2/3=1 4/5=2 6/7=3 8/10=4;
recode violence2 0/1=0 2/3=1 4/5=2 6/7=3 8/10=4;
recode sex2 0/1=0 2/3=1 4/5=2 6/7=3 8/10=4;
egen combo = group(profanity2 violence2 sex2);
* total content scores;
gen total = sex+violence+profanity;
* code restricted ratings in other countires;
gen aus_r = (ratingaustralia=="MA" | ratingaustralia=="MA 15+" | ratingaustralia=="R");
replace aus_r = . if distAUS == "";
gen uk_r = (ratinguk=="15" | ratinguk=="18" | ratinguk=="R18");
replace uk_r = . if distUK == "";
gen ont_r = (ratingontario=="18A"  | ratingontario=="AA" | ratingontario=="R" | ratingontario=="14A");
replace ont_r = . if distONT == "";
* create genre dummies;
qui tab genre, g(gd);




* TABLE 1;
/*SEE BELOW*/

* TABLE 2: LPM (OLS) models;
qui reg r major;
est store LPM1;
qui reg r major lnscale lndegree meanr;
est store LPM2;
qui reg r major lnscale lndegree meanr sex violence profanity;
est store LPM3;
qui reg r major lnscale lndegree meanr sex violence profanity vyd* ;
est store LPM4;
qui reg r major lnscale lndegree meanr sex violence profanity vyd* if total>6 & total<19;
est store LPMMARG;
qui areg r major lnscale lndegree meanr vyd*, abs(combo);
est store LPMSCOREFE;
estout _all, cells(b(star fmt(3)) se(par fmt(2))) stats(N r2)
    starlevels(+ 0.10 * 0.05 ** 0.01) drop(vyd*) label;
est clear;


* TABLE 3: LOGIT models and marginal effects;
qui logit r major lnscale lndegree meanr sex violence profanity vyd* ;
est store LOGIT1;
qui mfx;
est store LOGIT1MFX;
qui logit r major lnscale lndegree meanr sex violence profanity vyd*
  fnude mnude adultery homosexual rape gore suicide drugs;
est store LOGIT2;
qui mfx;
est store LOGIT2MFX;
qui clogit r major lnscale lndegree meanr  vyd*
  fnude mnude adultery homosexual rape gore suicide drugs, group(combo);
est store LOGITSCOREFE;
estout _all, cells(b(star fmt(3)) se(par fmt(2))) stats(N  r2_p ll)
    starlevels(+ 0.10 * 0.05 ** 0.01) drop(vyd* ) label  margin;
est clear;
 

* TABLE 4: INTL RESTRICTED RATINGS;
* RESTRICT TO 1998+;
gen majorUK = (distUK == "UNITED INTL. PICTURES"
             | distUK == "BUENA VISTA INTL."
             | distUK == "TWENTIETH CENTURY FOX"
             | distUK == "COLUMBIA TRISTAR"
             | distUK == "ENTERTAINMENT"
             | distUK == "WARNER BROS.");
replace majorUK = . if distUK == "";
label var majorUK "UK top six distributor";
gen majorAUS = (distAUS == "UIP"
             | distAUS == "ROADSHOW"
             | distAUS == "FOX"
             | distAUS == "BUENA VISTA INTL."
             | distAUS == "WARNER BROS."
             | distAUS == "SONY PICTURES INTL.");
replace majorAUS = . if distAUS == "";
label var majorAUS "Australia top six distributor";
gen majorONT = (distONT == "Warner Bros"
             | distONT == "Sony"
             | distONT == "Alliance-Atlantis"
             | distONT == "Buena Vista"
             | distONT == "Universal"
             | distONT == "Paramount");
replace majorONT = . if distONT == "";
label var majorONT "Canada top six distributor";
qui areg r major  vyd*  if year > 1997, abs(combo);
est store US;
qui areg uk_r major majorUK  vyd* if distUK != "" &  year > 1997 , abs(combo);
est store UK;
qui areg aus_r major majorAUS  vyd* if distAUS != "" & year > 1997, abs(combo);
est store AUS;
qui areg ont_r  major majorONT vyd* if distONT != "" & year > 1997, abs(combo);
est store ONT;
estout _all, cells(b(star fmt(3)) se(par fmt(2))) stats(N r2)
    starlevels(+ 0.10 * 0.05 ** 0.01) drop(vyd*) label;
est clear;



* TABLE 1 - DESCRIPTIVE STATISTICS;
tabstat r major lnscale lndegree meanr sex violence profanity 
   fnude mnude adultery homosexual rape gore suicide drugs  
   uk_r aus_r ont_r majorUK majorAUS majorONT
   , f(%9.2f) stats(mean sd min max) c(s);




* page 22: check on genre effects;
* test for joint significance on Variety coded genre dummies;
* each movie assigned to a single genre;
qui areg r major lnscale lndegree meanr vyd*, abs(combo);
est store BASELINE;
* the reference category is GD13 - Westenrn;
qui areg r major lnscale lndegree meanr vyd* gd1-gd12, abs(combo);
est store GENRE;
estout _all, cells(b(star fmt(3)) se(par fmt(2))) stats(N r2)
    starlevels(+ 0.10 * 0.05 ** 0.01) drop(vyd*) label;
est clear;
* test for joint significance;
test gd1+ gd2+ gd3+ gd4+ gd5+ gd6+ gd7+ gd8+ gd9+ gd10+ gd11+ gd12 = 0;

